# -*- coding: utf-8 -*-
from setuptools import setup

package_dir = \
{'': 'src'}

packages = \
['ppuri', 'ppuri.component', 'ppuri.scheme']

package_data = \
{'': ['*']}

modules = \
['py']
install_requires = \
['click>=8.1.3,<9.0.0', 'pyparsing>=3.0.9,<4.0.0']

setup_kwargs = {
    'name': 'ppuri',
    'version': '0.3.1',
    'description': 'A pyparsing based URI parser/scanner library',
    'long_description': '# ppURI\n\nA [pyparsing](https://pyparsing-docs.readthedocs.io/en/latest/) based URI parser/scanner library.\n\nInstall using pip or your tool of choice e.g.\n\n```\npip install ppuri\npoetry add ppuri\n```\n\n## Usage\n\n### Parsing\n\nEither import `ppuri.uri` and use the `parse` function to match and parse against all URI schemes e.g.\n\n```python\nfrom ppuri import uri\ninfo = uri.parse("https://www.example.com:443/a.path?q=aparam#afragment")\nprint(info)\n```\n\nprints\n\n```json\n{\n  "authority": { "address": "www.example.com", "port": "443" },\n  "fragment": "afragment",\n  "parameters": [{ "name": "q", "value": "aparam" }],\n  "path": "/a.path",\n  "scheme": "https",\n  "uri": "https://www.example.com:443/a.path?q=aparam#afragment"\n}\n```\n\nOr import a specific scheme\'s parse function.\n\n```python\nfrom ppuri.scheme import http\ninfo = http.parse()\n```\n\nand use that to parse\n\n### Scanning\n\nTo scan text for URIs use the `scan` method\n\n## Supported schemes\n\nCurrently supports the following schemes\n\n- http(s)\n- urn\n- data\n- file\n- mailto\n- about\n- aaa\n- coap\n- crid\n\n### Http(s)\n\n`parse_string` returns a dictionary of the form\n\n```json\n{\n  "scheme": "http or https",\n  "authority": {\n    "address": "hostname or ipv4 address or ipv6 address",\n    "port": "port number",\n    "username": "user name if provided",\n    "password": "pasword if provided"\n  },\n  "path": "path if provided",\n  "parameters": [\n    // list of parameters if provided\n    {\n      "name": "parameter name",\n      "value": "parameter value or None if not provided"\n    }\n  ],\n  "fragment": "fragment if provided",\n  "uri": "The full URI"\n}\n```\n\n### Urn\n\n`parse_string` returns a dictionary of the form\n\n```json\n{\n  "scheme": "urn",\n  "nid": "Namespace Identifier",\n  "nss": "Namespace Specific String",\n  "uri": "The full URI"\n}\n```\n\n### MailTo\n\n`parse_string` returns a dictionary of the form\n\n```json\n{\n  "scheme": "mailto",\n  "addresses": [\n    "List of email addresses",\n  ]\n  "parameters": [\n    "list of parameters if provided",\n    {\n        "name": "bcc",\n        "value": "dave@example.com"\n    }\n  ],\n  "uri": "The full URI"\n}\n```\n\n### Data\n\n`parse_string` returns a dictionary of the form\n\n```json\n{\n  "scheme": "data",\n  "type": "Mime type",\n  "subtype": "Mime Subtype",\n  "encoding": "base64 if specified",\n  "data": "The actual data",\n  "uri": "The full URI"\n}\n```\n\n### File\n\n`parse_string` returns a dictionary of the form\n\n```json\n{\n  "scheme": "file",\n  "path": "The /file/path",\n  "uri": "The full URI"\n}\n```\n\n## Package Status\n\n![GitHub Workflow Status](https://img.shields.io/github/workflow/status/sffjunkie/ppuri/ppuri-test) ![PyPI - Downloads](https://img.shields.io/pypi/dm/ppuri)\n',
    'author': 'Simon Kennedy',
    'author_email': 'sffjunkie+code@gmail.com',
    'maintainer': None,
    'maintainer_email': None,
    'url': None,
    'package_dir': package_dir,
    'packages': packages,
    'package_data': package_data,
    'py_modules': modules,
    'install_requires': install_requires,
    'python_requires': '>=3.10,<4.0',
}


setup(**setup_kwargs)
